Package 'pladj'

Title: Partial leverage adjusted degrees of freedom as proposed by Kranz (2024)
Description: Fast computation of PL matrices, interfaces with fixest and lm
Authors: Sebastian Kranz [aut, cre]
Maintainer: Sebastian Kranz <[email protected]>
License: MIT
Version: 0.1.0
Built: 2026-05-15 10:20:58 UTC
Source: https://github.com/skranz/pladj

Help Index


Degrees of freedom using the partial leverages adjustment proposed by Kranz (2024)

Description

Use these degree of freedoms for the t-test of HC1 or HC2 standard errors Only makes sense for these hetereoksedasticity robust standard errors. Does not work for cluster robust standard errors

Usage

dof_pladj(x)

Arguments

x

A regression result from lm or feols. Alternatively, a matrix of partial leverage generated with partial_leverages.